@@ -1,13 +1,40 @@
-XNAT_RESOURCE_NAMES = ['FREESURFER6', 'FREESURFER6_HIRES']
+XNAT_RESOURCE_NAMES = ['FREESURFER6', 'FREESURFER6_HIRES', 'FREESURFER7']
+
+
+def amygNucVolumes(self, mode='T1'):
+    """Returns amygdala nuclei volumetry as estimated by FreeSurfer
+    `recon-all`."""
+    import pandas as pd
+
+    if self.label().startswith('FREESURFER6'):
+        raise NotImplementedError('Not available in FreeSurfer 6')
+
+    table = []
+    files = list(self.files('*h.amygNucVolumes-%s.v*.txt' % mode))
+    for f in files:
+        uri = f._uri
+
+        res = self._intf.get(uri).text.split('\n')
+        d1 = dict([each.split(' ') for each in res[:-1]])
+        d2 = dict([('%s' % k, float(v))
+                  for k, v in d1.items()])
+
+        side = {'l': 'left', 'r': 'right'}[uri.split('/')[-1][0]]
+        for region, value in d2.items():
+            row = [side, region, value]
+            table.append(row)
+
+    columns = ['side', 'region', 'value']
+    return pd.DataFrame(table, columns=columns)
 
 
 def hippoSfVolumes(self, mode='T1'):
-    ''' Returns hippocampal subfield volumetry as estimated by FreeSurfer
-    `recon-all`.'''
+    """Returns hippocampal subfield volumetry as estimated by FreeSurfer
+    `recon-all`."""
     import pandas as pd
 
     table = []
-    files = list(self.files('*h.hippoSfVolumes-%s.v10.txt' % mode))
+    files = list(self.files('*h.hippoSfVolumes-%s.v*.txt' % mode))
     for f in files:
         uri = f._uri
 
@@ -26,7 +53,7 @@ def hippoSfVolumes(self, mode='T1'):
 
 
 def aparc(self, atlas='desikan-killiany'):
-    ''' Returns cortical features as estimated by FreeSurfer `recon-all`.'''
+    """Returns cortical features as estimated by FreeSurfer `recon-all`."""
 
     import pandas as pd
 
@@ -61,25 +88,18 @@ def aparc(self, atlas='desikan-killiany'):
         res = self._intf.get(uri).text.split('\n')
 
         res2 = [e for e in res if e.startswith('# Measure ')]
-        for each in volumes:
-            m = float([e for e in res2
-                       if each in e.split(', ')[1]][0].split(', ')[-2])
-            table.append([None, 'Volume_mm3', each, m])
 
-        for each in thickness:
-            m = float([e for e in res2
-                       if each in e.split(', ')[1]][0].split(', ')[-2])
-            table.append([None, 'Thickness_mm', each, m])
+        measurements = {'Volume_mm3': volumes,
+                        'Thickness_mm': thickness,
+                        'SurfArea_mm2': surfaces,
+                        'unitless': unitless}
 
-        for each in surfaces:
-            m = float([e for e in res2
-                       if each in e.split(', ')[1]][0].split(', ')[-2])
-            table.append([None, 'SurfArea_mm2', each, m])
-
-        for each in unitless:
-            m = float([e for e in res2
-                       if each in e.split(', ')[1]][0].split(', ')[-2])
-            table.append([None, 'unitless', each, m])
+        for unit, data in measurements.items():
+            for each in data:
+                m = [e for e in res2 if each == e.split(', ')[1]]
+                if len(m) == 1:
+                    m = float(m[0].split(', ')[-2])
+                    table.append([None, unit, each, m])        
 
         res2 = [e for e in res if not e.startswith('#')]
         d2 = [[each for each in e.split(' ') if each != ''] for e in res2]
@@ -112,6 +132,9 @@ def aseg(self):
                'CerebralWhiteMatterVol', 'SubCortGrayVol', 'TotalGrayVol',
                'SupraTentorialVol', 'SupraTentorialVolNotVent',
                'SupraTentorialVolNotVentVox', 'MaskVol', 'eTIV']
+    if self.label() == 'FREESURFER7':
+        deprecated = ['BrainSegVolNotVentSurf', 'SupraTentorialVolNotVentVox']
+        volumes = [v for v in volumes if v not in deprecated]
 
     unitless = ['BrainSegVol-to-eTIV', 'MaskVol-to-eTIV', 'lhSurfaceHoles',
                 'rhSurfaceHoles', 'SurfaceHoles']
