@@ -22,10 +22,16 @@ def landau_signature(self, optimized=True, reference_region='vermis'):
     Landau et al., Ann Neurol., 2012."""
 
     df = self.quantification_results()
-    q = 'atlas.isna() & reference_region == "{reference_region}" &'\
+
+    q = 'reference_region == "{reference_region}" &'\
         ' measurement == "suvr"'.format(reference_region=reference_region)
 
     q += ' & %soptimized_pet' % {True: '', False: '~'}[optimized]
     df = df.query(q)
     df = df.query('region.str.contains("landau")', engine='python')
+    
+    assert(len(set(df['atlas'])) == 1)
+    del df['atlas']
+    assert(len(set(df['optimized_pet'])) == 1)
+
     return df
